@@ -7,12 +7,12 @@ from stepwise import (
 )
 from stepwise_mol_bio import (
         Main, UsageError,
-        merge_dicts, format_min, join_lists,
+        merge_dicts, format_min,
 )
 from freezerbox import (
         ReagentConfig, MakerArgsConfig,
         parse_volume_uL, parse_time_m, parse_temp_C, convert_conc_unit,
-        unanimous, iter_combo_makers, group_by_identity, normalize_seq,
+        unanimous, group_by_identity, normalize_seq, join_lists,
 )
 from appcli import DocoptConfig, Key, Method
 from inform import plural, warn
@@ -184,13 +184,13 @@ Configuration:
         Lists of footnotes for the reaction setup, incubation, and DNase 
         treatment steps, respectively.
 
-Database Synthesis:
-    In vitro transcription reactions can appear in the "Synthesis" column 
-    of a FreezerBox database:
+Database:
+    In vitro transcription reactions can appear in the "Synthesis" column of a 
+    FreezerBox database.  The associated database entry will automatically be 
+    considered ssRNA, e.g. for the purpose of molecular weight calculations:
 
-        ivt <fields>...
-
-    The following fields are understood:
+        ivt template=<tag> [preset=<preset>] [volume=<µL>] [time=<min>]
+            [temp=<°C>]
 
     template=<tag>
         See `<templates>`.  Only one template can be specified.
@@ -306,7 +306,7 @@ Template Preparation:
     )
     template_stock_ng_uL = appcli.param(
             Key(DocoptConfig, '--template-stock', cast=float),
-            Key(TemplateConfig, 'conc_ng_uL', cast=unanimous),
+            Key(TemplateConfig, 'conc_ng_uL', cast=min),
             default=None,
     )
     short = appcli.param(
@@ -365,28 +365,22 @@ Template Preparation:
             default_factory=dict,
     )
 
+    group_by = {
+        'preset': group_by_identity,
+        'volume_uL': group_by_identity,
+        'incubation_times_min': group_by_identity,
+        'incubation_temp_C': group_by_identity,
+    }
+    merge_by = {
+        'templates': join_lists,
+    }
+
     def __init__(self, templates):
         self.templates = templates
 
     def __repr__(self):
         return f'Ivt(templates={self.templates!r})'
 
-    @classmethod
-    def make(cls, db, products):
-        yield from iter_combo_makers(
-                cls.from_params,
-                map(cls.from_product, products),
-                group_by={
-                    'preset': group_by_identity,
-                    'volume_uL': group_by_identity,
-                    'incubation_times_min': group_by_identity,
-                    'incubation_temp_C': group_by_identity,
-                },
-                merge_by={
-                    'templates': join_lists,
-                },
-        )
-
     def get_reaction(self):
         rxn = self.reaction_prototype.copy()
         rxn.num_reactions = len(self.templates)
@@ -411,6 +405,7 @@ Template Preparation:
 
             rxn['rNTP mix'].volume = sum(x.volume for x in rntps)
             rxn['rNTP mix'].stock_conc = sum(x.stock_conc for x in rntps) / len(rntps)
+            rxn['rNTP mix'].master_mix = all(x.master_mix for x in rntps)
             rxn['rNTP mix'].order = rntps[0].order
 
             for rntp in rntps:
@@ -484,7 +479,6 @@ Template Preparation:
     def get_product_molecule(self):
         return 'ssRNA'
 
-
 def transcribe(template_seq):
     t7_promoter = 'TAATACGACTCACTATA'
     template_seq = normalize_seq(template_seq)
